[**高级选项**](./introduction.md) > **翻译服务文档** _(当前)_

---

### 通过命令行查看可用翻译服务

您可以通过在命令行中打印帮助信息来确认可用的翻译服务及其使用方法。

```bash
pdf2zh_next -h
```

在帮助信息的末尾，您可以查看有关不同翻译服务的详细信息。

---

> [!CAUTION]
> 以下内容是为 pdf2zh 1.x 版本准备的，尚未针对 2.x 版本进行更新。因此，信息可能**已过时**。
>
> 一旦文章内容与新版本保持一致，此警告信息将被移除。

* [Google 翻译](https://cloud.google.com/translate/docs)
* [DeepL](https://developers.deepl.com/docs/api-reference/translate)
* [DeepLX](https://github.com/OwO-Network/DeepLX)
* [OpenAI](https://platform.openai.com/docs/api-reference/introduction)
* [Ollama](https://github.com/ollama/ollama/blob/main/docs/api.md)
* [Azure](https://learn.microsoft.com/en-us/azure/ai-services/translator/)
* [智谱](https://bigmodel.cn/)
* [深度求索](https://api-docs.deepseek.com/)

#### 使用不同翻译服务进行翻译

我们已为每项翻译服务提供了详细的[环境变量](https://chatgpt.com/share/6734a83d-9d48-800e-8a46-f57ca6e8bcb4)需求表。请确保在使用相应服务前完成配置。

| **翻译器**       | **服务**    | **环境变量**                                             | **默认值**                                       | **备注**                                                                                                                                                                                                                  |
| -------------------- | -------------- | --------------------------------------------------------------------- | -------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| **Google (默认)** | `google`       | 无                                                                  | 不适用                                                      | 无                                                                                                                                                                                                                       |
| **Bing**             | `bing`         | 无                                                                  | 不适用                                                      | 无                                                                                                                                                                                                                       |
| **DeepL**            | `deepl`        | `DEEPL_AUTH_KEY`                                                      | `[您的密钥]`                                             | 参见 [DeepL](https://support.deepl.com/hc/en-us/articles/360020695820-API-Key-for-DeepL-s-API)                                                                                                                              |
| **DeepLX**           | `deeplx`       | `DEEPLX_ENDPOINT`                                                     | `https://api.deepl.com/translate`                        | 参见 [DeepLX](https://github.com/OwO-Network/DeepLX)                                                                                                                                                                        |
| **Ollama**           | `ollama`       | `OLLAMA_HOST`, `OLLAMA_MODEL`                                         | `http://127.0.0.1:11434`, `gemma2`                       | 参见 [Ollama](https://github.com/ollama/ollama)                                                                                                                                                                             |
| **Xinference**       | `xinference`   | `XINFERENCE_HOST`, `XINFERENCE_MODEL`                                 | `http://127.0.0.1:9997`, `gemma-2-it`                    | 参见 [Xinference](https://github.com/xorbitsai/inference)                                                                                                                                                                   |
| **OpenAI**           | `openai`       | `OPENAI_BASE_URL`, `OPENAI_API_KEY`, `OPENAI_MODEL`                   | `https://api.openai.com/v1`, `[您的密钥]`, `gpt-4o-mini` | 参见 [OpenAI](https://platform.openai.com/docs/overview)                                                                                                                                                                    |
| **AzureOpenAI**      | `azure-openai` | `AZURE_OPENAI_BASE_URL`, `AZURE_OPENAI_API_KEY`, `AZURE_OPENAI_MODEL` | `[您的终端节点]`, `[您的密钥]`, `gpt-4o-mini`           | 参见 [Azure OpenAI](https://learn.microsoft.com/zh-cn/azure/ai-services/openai/chatgpt-quickstart?tabs=command-line%2Cjavascript-keyless%2Ctypescript-keyless%2Cpython&pivots=programming-language-python)                  |
| **智谱**            | `zhipu`        | `ZHIPU_API_KEY`, `ZHIPU_MODEL`                                        | `[您的密钥]`, `glm-4-flash`                              | 参见[智谱](https://open.bigmodel.cn/dev/api/thirdparty-frame/openai-sdk)                                                                                                                                                  |
| **ModelScope**       | `ModelScope`   | `MODELSCOPE_API_KEY`, `MODELSCOPE_MODEL`                              | `[Your Key]`, `Qwen/Qwen2.5-Coder-32B-Instruct`          | 参见 [ModelScope](https://www.modelscope.cn/docs/model-service/API-Inference/intro)                                                                                                                                         |
| **硅智云**          | `silicon`      | `SILICON_API_KEY`, `SILICON_MODEL`                                    | `[您的密钥]`, `Qwen/Qwen2.5-7B-Instruct`                 | 参见[硅智云文档](https://docs.siliconflow.cn/quickstart)                                                                                                                                                                 |
| **Gemini**           | `gemini`       | `GEMINI_API_KEY`, `GEMINI_MODEL`                                      | `[Your Key]`, `gemini-1.5-flash`                         | 参见 [Gemini](https://ai.google.dev/gemini-api/docs/openai)                                                                                                                                                                 |
| **Azure**            | `azure`        | `AZURE_ENDPOINT`, `AZURE_API_KEY`                                     | `https://api.translator.azure.cn`, `[Your Key]`          | 参阅 [Azure](https://docs.azure.cn/en-us/ai-services/translator/text-translation-overview)                                                                                                                                  |
| **腾讯云**          | `tencent`      | `TENCENTCLOUD_SECRET_ID`, `TENCENTCLOUD_SECRET_KEY`                   | `[您的ID]`, `[您的密钥]`                                | 参见[腾讯云](https://www.tencentcloud.com/products/tmt?from_qcintl=122110104)                                                                                                                                             |
| **Dify**             | `dify`         | `DIFY_API_URL`, `DIFY_API_KEY`                                        | `[您的 DIFY URL]`, `[您的密钥]`                          | 参见 [Dify](https://github.com/langgenius/dify)，需要在 Dify 的工作流输入中定义三个变量：lang_out、lang_in 和 text。                                                                                  |
| **AnythingLLM**      | `anythingllm`  | `AnythingLLM_URL`, `AnythingLLM_APIKEY`                               | `[您的 AnythingLLM URL]`, `[您的密钥]`                   | 参见 [anything-llm](https://github.com/Mintplex-Labs/anything-llm)                                                                                                                                                          |
| **Argos Translate**  | `argos`        |                                                                       |                                                          | 参见 [argos-translate](https://github.com/argosopentech/argos-translate)                                                                                                                                                    |
| **Grok**             | `grok`         | `GORK_API_KEY`, `GORK_MODEL`                                          | `[您的 GORK_API_KEY]`, `grok-2-1212`                     | 参见 [Grok](https://docs.x.ai/docs/overview)                                                                                                                                                                                |
| **Groq**             | `groq`         | `GROQ_API_KEY`, `GROQ_MODEL`                                          | `[您的 GROQ_API_KEY]`, `llama-3-3-70b-versatile`         | 参见 [Groq](https://console.groq.com/docs/models)                                                                                                                                                                           |
| **DeepSeek**         | `deepseek`     | `DEEPSEEK_API_KEY`, `DEEPSEEK_MODEL`                                  | `[您的 DEEPSEEK_API_KEY]`, `deepseek-chat`               | 参见 [DeepSeek](https://www.deepseek.com/)                                                                                                                                                                                  |
| **类 OpenAI**     | `openailiked`  | `OPENAILIKED_BASE_URL`, `OPENAILIKED_API_KEY`, `OPENAILIKED_MODEL`    | `url`, `[您的密钥]`, `模型名称`                        | 无                                                                                                                                                                                                                       |
| **阿里通义翻译** | `qwen-mt`  | `ALI_MODEL`, `ALI_API_KEY`, `ALI_DOMAINS`                             | `qwen-mt-turbo`, `[您的密钥]`, `scientific paper`        | 暂不支持繁体中文，将统一译为简体中文。详见[通义千问机器翻译](https://bailian.console.aliyun.com/?spm=5176.28197581.0.0.72e329a4HRxe99#/model-market/detail/qwen-mt-turbo) |

对于与 OpenAI API 兼容但未在上表中列出的大型语言模型，您可以使用与上表中 OpenAI 相同的方法设置环境变量。

使用 `-s service` 或 `-s service:model` 来指定服务：

```bash
pdf2zh_next example.pdf -s openai:gpt-4o-mini
```

或者通过环境变量指定模型：

```bash
set OPENAI_MODEL=gpt-4o-mini
pdf2zh_next example.pdf -s openai
```

对于 PowerShell 用户：

```shell
$env:OPENAI_MODEL = gpt-4o-mini
pdf2zh_next example.pdf -s openai
```

<div align="right"> 
<h6><small>本页面的部分内容由 GPT 翻译，可能包含错误。</small></h6>